==> jc-1.4.0.tar.gz: soot/jimple/toolkits/scalar/pre/NotIsolatedAnalysis.h <==
// public class soot.jimple.toolkits.scalar.pre.NotIsolatedAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9a99d059deb6fd7 soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class 722d252e8e2e5e52 soot_toolkits_scalar_BackwardFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_BackwardFlowAnalysis

#include "soot/toolkits/scalar/BackwardFlowAnalysis.h"

#ifndef _JC_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis_H_
#define _JC_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;
struct _jc_soot_toolkits_scalar_BoundedFlowSet$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_refs	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$refs	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$nonrefs	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vmethods	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtable	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtype	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$_init$eb5ba47e5c5a5d72(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$_init$03d2410e1dbae8ba(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$copy$0585c1f937996187(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *);
extern void _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$merge$37b91166a64cb493(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method_info$copy$0585c1f937996187;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method_info$newInitialFlow$8126aa62e2c0e28e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vmethods {
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *);
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vmethods	soot_toolkits_scalar_BackwardFlowAnalysis;
	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vmethods	soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_refs {
	struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object	*unitToLatest;
	struct _jc_object	*unitToGen;
	struct _jc_object	*set;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$refs {
    _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_refs	soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis;
    _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_refs	soot_toolkits_scalar_BackwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_BackwardFlowAnalysis;
    _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_nonrefs	soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object {
	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtype _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/scalar/pre/NotIsolatedAnalysis.h <==
// public class soot.jimple.toolkits.scalar.pre.NotIsolatedAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9a99d059deb6fd7 soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class 722d252e8e2e5e52 soot_toolkits_scalar_BackwardFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_BackwardFlowAnalysis

#include "soot/toolkits/scalar/BackwardFlowAnalysis.h"

#ifndef _JC_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis_H_
#define _JC_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;
struct _jc_soot_toolkits_scalar_BoundedFlowSet$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_refs	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$refs	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$nonrefs	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vmethods	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtable	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtype	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$_init$eb5ba47e5c5a5d72(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$_init$03d2410e1dbae8ba(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$copy$0585c1f937996187(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$merge$37b91166a64cb493(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method_info$copy$0585c1f937996187;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$method_info$newInitialFlow$8126aa62e2c0e28e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vmethods {
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *) _JC_JCNI_ATTR;
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vmethods	soot_toolkits_scalar_BackwardFlowAnalysis;
	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vmethods	soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_refs {
	struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object	*unitToLatest;
	struct _jc_object	*unitToGen;
	struct _jc_object	*set;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$refs {
    _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_refs	soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis;
    _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_refs	soot_toolkits_scalar_BackwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_BackwardFlowAnalysis;
    _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$sub_nonrefs	soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$object {
	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$vtype _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_pre_NotIsolatedAnalysis_H_ */
